@@ -1,3 +1,5 @@
+from __future__ import print_function
+
 import re
 import os
 
@@ -17,8 +19,7 @@ class Command(BaseCommand):
         try:
             app_module = models.get_app(app)
         except ImproperlyConfigured:
-            print("There is no enabled application matching '%s'." % app)
-            return
+            self.error("There is no enabled application matching '%s'." % app)
 
         migrations = Migrations(app)
         new_filename = migrations.next_filename(name)
@@ -27,6 +28,11 @@ class Command(BaseCommand):
             fp.write(MIGRATION_TEMPLATE)
 
 
+    def error(self, message, code=1):
+        print(message, file=sys.stderr)
+        sys.exit(code)
+
+
 MIGRATION_TEMPLATE = """# -*- coding: utf-8 -*-
 
 
